@@ -62,7 +62,9 @@ status_icon_popup_menu (GtkStatusIcon *_status_icon, guint button, guint activat
 		gtk_widget_show_all (menu);
 	}
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, gtk_status_icon_position_menu, _status_icon, button, activate_time);
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static void
@@ -70,7 +72,9 @@ create_status_icon (void)
 {
 	if (!status_icon_or_null)
 	{
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 		GtkStatusIcon *status_icon = gtk_status_icon_new_from_icon_name ("org.xfce.taskmanager");
+G_GNUC_END_IGNORE_DEPRECATIONS
 		g_signal_connect (status_icon, "activate", G_CALLBACK (status_icon_activated), NULL);
 		g_signal_connect (status_icon, "popup-menu", G_CALLBACK (status_icon_popup_menu), NULL);
 		status_icon_or_null = status_icon;
@@ -80,7 +84,9 @@ create_status_icon (void)
 static gboolean
 status_icon_get_visible (void)
 {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	return status_icon_or_null && gtk_status_icon_get_visible (status_icon_or_null);
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static void
@@ -91,11 +97,15 @@ show_hide_status_icon (void)
 	if (show_status_icon)
 	{
 		create_status_icon ();
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 		gtk_status_icon_set_visible (status_icon_or_null, TRUE);
+G_GNUC_END_IGNORE_DEPRECATIONS
 	}
 	else if (status_icon_get_visible ())
 	{
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 		gtk_status_icon_set_visible (status_icon_or_null, FALSE);
+G_GNUC_END_IGNORE_DEPRECATIONS
 	}
 }
 
@@ -103,7 +113,8 @@ static void
 destroy_window (void)
 {
 	if (gtk_main_level () > 0) {
-		xfconf_shutdown();
+		if (timer_id > 0)
+			g_source_remove (timer_id);
 		gtk_main_quit ();
 	}
 }
@@ -113,7 +124,8 @@ delete_window (void)
 {
 	if (!status_icon_get_visible ())
 	{
-		xfconf_shutdown();
+		if (timer_id > 0)
+			g_source_remove (timer_id);
 		gtk_main_quit ();
 		return FALSE;
 	}
@@ -159,7 +171,9 @@ collect_data (void)
 				"<b>Memory:</b> %s\n"
 				"<b>Swap:</b> %s"),
 				num_processes, cpu, memory_info, swap_info);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 		gtk_status_icon_set_tooltip_markup (GTK_STATUS_ICON (status_icon_or_null), tooltip);
+G_GNUC_END_IGNORE_DEPRECATIONS
 	}
 
 	xtm_task_manager_update_model (task_manager);
@@ -211,8 +225,11 @@ int main (int argc, char *argv[])
 	if (!g_option_context_parse (opt_context, &argc, &argv, &error))
 	{
 		g_print ("Unable to parse arguments: %s\n", error->message);
+		g_error_free (error);
+		g_option_context_free (opt_context);
 		return 1;
 	}
+	g_option_context_free (opt_context);
 
 	app = g_application_new ("xfce.taskmanager", 0);
 	g_application_register (G_APPLICATION (app), NULL, &error);
@@ -247,7 +264,7 @@ int main (int argc, char *argv[])
 	xtm_settings_bind_xfconf (settings, channel);
 	show_hide_status_icon ();
 
-	window = xtm_process_window_new ();
+	window = g_object_ref_sink (xtm_process_window_new ());
 
 	if (!start_hidden)
 		gtk_widget_show (window);
@@ -271,8 +288,12 @@ int main (int argc, char *argv[])
 	else
 		g_warning ("Nothing to do: activate hiding to the notification area when using --start-hidden");
 
-	if (timer_id > 0)
-		g_source_remove (timer_id);
+	g_object_unref (task_manager);
+	g_object_unref (window);
+	g_object_unref (settings);
+	if (status_icon_or_null != NULL)
+		g_object_unref (status_icon_or_null);
+	xfconf_shutdown();
 
 	return 0;
 }
