@@ -40,6 +40,7 @@ struct _XtmProcessMonitor
 };
 G_DEFINE_TYPE (XtmProcessMonitor, xtm_process_monitor, GTK_TYPE_DRAWING_AREA)
 
+static void	xtm_process_monitor_finalize		(GObject *object);
 static void	xtm_process_monitor_get_property	(GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
 static void	xtm_process_monitor_set_property	(GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
 static gboolean	xtm_process_monitor_draw		(GtkWidget *widget, cairo_t *cr);
@@ -53,6 +54,7 @@ xtm_process_monitor_class_init (XtmProcessMonitorClass *klass)
 	GObjectClass *class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 	xtm_process_monitor_parent_class = g_type_class_peek_parent (klass);
+	class->finalize = xtm_process_monitor_finalize;
 	class->get_property = xtm_process_monitor_get_property;
 	class->set_property = xtm_process_monitor_set_property;
 	widget_class->draw = xtm_process_monitor_draw;
@@ -70,6 +72,17 @@ xtm_process_monitor_init (XtmProcessMonitor *monitor)
 	monitor->history_swap = g_array_new (FALSE, TRUE, sizeof (gfloat));
 }
 
+static void
+xtm_process_monitor_finalize (GObject *object)
+{
+	XtmProcessMonitor *monitor = XTM_PROCESS_MONITOR (object);
+
+	g_array_free (monitor->history, TRUE);
+	g_array_free (monitor->history_swap, TRUE);
+
+	G_OBJECT_CLASS (xtm_process_monitor_parent_class)->finalize (object);
+}
+
 static void
 xtm_process_monitor_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec)
 {
@@ -134,8 +147,7 @@ xtm_process_monitor_graph_surface_create (XtmProcessMonitor *monitor, gint width
 {
 	cairo_t *cr;
 	cairo_surface_t *graph_surface;
-	gfloat *peak;
-	gdouble step_size;
+	gdouble peak, step_size;
 	gint i;
 
 	if (monitor->history->len <= 1)
@@ -155,11 +167,17 @@ xtm_process_monitor_graph_surface_create (XtmProcessMonitor *monitor, gint width
 	cairo_set_line_join (cr, CAIRO_LINE_JOIN_ROUND);
 	cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
 	cairo_move_to (cr, width, height);
+
+	/* Create a line before the call to cairo_translate,
+	 * to avoid creating a downward sloping line going off the graph */
+	peak = g_array_index (monitor->history, gfloat, 0);
+	cairo_line_to (cr, width, (1.0 - peak) * height);
+
 	for (i = 0; (step_size * (i - 1)) <= width; i++)
 	{
-		peak = &g_array_index (monitor->history, gfloat, i);
+		peak = g_array_index (monitor->history, gfloat, i);
 		cairo_translate (cr, -step_size, 0);
-		cairo_line_to (cr, width, (1.0 - ((gdouble)(*peak))) * height);
+		cairo_line_to (cr, width, (1.0 - peak) * height);
 	}
 
 	if (monitor->type == 0)
@@ -180,11 +198,15 @@ xtm_process_monitor_graph_surface_create (XtmProcessMonitor *monitor, gint width
 	{
 		cairo_translate (cr, step_size * i, 0);
 		cairo_move_to (cr, width, height);
+
+		peak = g_array_index (monitor->history_swap, gfloat, 0);
+		cairo_line_to (cr, width, (1.0 - peak) * height);
+
 		for (i = 0; (step_size * (i - 1)) <= width; i++)
 		{
-			peak = &g_array_index (monitor->history_swap, gfloat, i);
+			peak = g_array_index (monitor->history_swap, gfloat, i);
 			cairo_translate (cr, -step_size, 0);
-			cairo_line_to (cr, width, (1.0 - ((gdouble)(*peak))) * height);
+			cairo_line_to (cr, width, (1.0 - peak) * height);
 		}
 		cairo_set_source_rgba (cr, 0.33, 0.04, 0.16, 0.3);
 		cairo_line_to (cr, width, height);
