@@ -8,6 +8,10 @@
  * (at your option) any later version.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <kstat.h>
 #include <sys/types.h>
 #include <sys/stat.h>
