@@ -26,6 +26,7 @@
 
 #include "task-manager.h"
 #ifdef HAVE_WNCK
+#include <gdk/gdkx.h>
 #include "app-manager.h"
 #endif
 #include "process-tree-view.h" /* for the columns of the model */
@@ -93,7 +94,9 @@ static void
 xtm_task_manager_init (XtmTaskManager *manager)
 {
 #ifdef HAVE_WNCK
-	manager->app_manager = xtm_app_manager_new ();
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ())) {
+		manager->app_manager = xtm_app_manager_new ();
+	}
 #endif
 	manager->tasks = g_array_new (FALSE, FALSE, sizeof (Task));
 
@@ -111,9 +114,13 @@ xtm_task_manager_finalize (GObject *object)
 	XtmTaskManager *manager = XTM_TASK_MANAGER (object);
 	g_array_free (manager->tasks, TRUE);
 #ifdef HAVE_WNCK
-	g_object_unref (manager->app_manager);
+	if (manager->app_manager != NULL) {
+		g_object_unref (manager->app_manager);
+	}
 #endif
 	g_object_unref (settings);
+
+	G_OBJECT_CLASS (xtm_task_manager_parent_class)->finalize (object);
 }
 
 static void
@@ -213,8 +220,8 @@ model_mark_tree_iter_as_removed (GtkTreeModel *model, GtkTreeIter *iter, glong t
 	gtk_list_store_set (GTK_LIST_STORE (model), iter,
 		XTM_PTV_COLUMN_CPU, 0.0,
 		XTM_PTV_COLUMN_CPU_STR, "-",
-		XTM_PTV_COLUMN_BACKGROUND, "#e57373",
-		XTM_PTV_COLUMN_FOREGROUND, "#000000",
+		XTM_PTV_COLUMN_BACKGROUND, XTM_LEGEND_COLOR_TERMINATING,
+		XTM_PTV_COLUMN_FOREGROUND, XTM_LEGEND_COLOR_NONE,
 		XTM_PTV_COLUMN_TIMESTAMP, timestamp,
 		-1);
 }
@@ -235,8 +242,8 @@ model_update_tree_iter (XtmTaskManager *manager, GtkTreeIter *iter, glong timest
 	gchar *old_state;
 	gchar *background, *foreground;
 #ifdef HAVE_WNCK
-	App *app = xtm_app_manager_get_app_from_pid (manager->app_manager, task->pid);
-	GdkPixbuf *icon;
+	App *app = manager->app_manager != NULL ? xtm_app_manager_get_app_from_pid (manager->app_manager, task->pid) : NULL;
+	GdkPixbuf *icon = NULL;
 #endif
 
 	vsz = g_format_size_full (task->vsz, G_FORMAT_SIZE_IEC_UNITS);
@@ -254,7 +261,9 @@ model_update_tree_iter (XtmTaskManager *manager, GtkTreeIter *iter, glong timest
 			-1);
 
 #ifdef HAVE_WNCK
-	if (app != NULL && icon == NULL)
+	if (icon != NULL)
+		g_object_unref (icon);
+	else if (app != NULL)
 		gtk_list_store_set (GTK_LIST_STORE (model), iter, XTM_PTV_COLUMN_ICON, app->icon, -1);
 
 	if (app != NULL && full_cmdline == FALSE)
@@ -276,20 +285,24 @@ model_update_tree_iter (XtmTaskManager *manager, GtkTreeIter *iter, glong timest
 	if (g_strcmp0 (task->state, old_state) != 0 && background == NULL)
 	{
 		/* Set yellow color for changing state */
-		background = g_strdup ("#fff176");
-		foreground = g_strdup ("#000000");
+		g_free (background);
+		g_free (foreground);
+		background = g_strdup (XTM_LEGEND_COLOR_CHANGING);
+		foreground = g_strdup (XTM_LEGEND_COLOR_NONE);
 		old_timestamp = timestamp - TIMESTAMP_DELTA + 3;
 	}
 
 	if (timestamp != 0 && (timestamp - old_timestamp) <= TIMESTAMP_DELTA)
 	{
 		/* Set green color for started task */
-		background = (background == NULL) ? g_strdup ("#aed581") : background;
-		foreground = (foreground == NULL) ? g_strdup ("#000000") : foreground;
+		background = (background == NULL) ? g_strdup (XTM_LEGEND_COLOR_STARTING) : background;
+		foreground = (foreground == NULL) ? g_strdup (XTM_LEGEND_COLOR_NONE) : foreground;
 	}
 	else
 	{
 		/* Reset color */
+		g_free (background);
+		g_free (foreground);
 		background = NULL;
 		foreground = NULL;
 	}
